@@ -1,4 +1,4 @@
-{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE FlexibleContexts, ScopedTypeVariables #-}
 --------------------------------------------------------------------------------
 -- | Miscellaneous string manipulation functions.
 module Hakyll.Core.Util.String
@@ -6,13 +6,13 @@ module Hakyll.Core.Util.String
     , replaceAll
     , splitAll
     , needlePrefix
+    , removeWinPathSeparator
     ) where
 
 
 --------------------------------------------------------------------------------
 import Data.Char (isSpace)
 import Data.List (isPrefixOf)
-import Data.Maybe (listToMaybe)
 import Text.Regex.TDFA ((=~~))
 
 
@@ -32,12 +32,10 @@ replaceAll :: String              -- ^ Pattern
            -> String              -- ^ Result
 replaceAll pattern f source = replaceAll' source
   where
-    replaceAll' src = case listToMaybe (src =~~ pattern) of
-        Nothing     -> src
-        Just (o, l) ->
-            let (before, tmp) = splitAt o src
-                (capture, after) = splitAt l tmp
-            in before ++ f capture ++ replaceAll' after
+    replaceAll' ""  = ""
+    replaceAll' src = case src =~~ pattern of
+        Nothing                       -> src
+        Just (before, capture, after) -> before ++ f capture ++ replaceAll' after
 
 
 --------------------------------------------------------------------------------
@@ -48,11 +46,10 @@ splitAll :: String    -- ^ Pattern
          -> [String]  -- ^ Result
 splitAll pattern = filter (not . null) . splitAll'
   where
-    splitAll' src = case listToMaybe (src =~~ pattern) of
-        Nothing     -> [src]
-        Just (o, l) ->
-            let (before, tmp) = splitAt o src
-            in before : splitAll' (drop l tmp)
+    splitAll' ""  = []
+    splitAll' src = case src =~~ pattern of
+        Nothing                         -> [src]
+        Just (before, _::String, after) -> before : splitAll' after
 
 
 
@@ -76,3 +73,9 @@ needlePrefix needle haystack = go [] haystack
     go acc xss@(x:xs)
         | needle `isPrefixOf` xss = Just $ reverse acc
         | otherwise               = go (x : acc) xs
+
+
+--------------------------------------------------------------------------------
+-- | Translate native Windows path separators '\\' to '/' if present.
+removeWinPathSeparator :: String -> String
+removeWinPathSeparator = concatMap (\c -> if c == '\\' then ['/'] else [c])
\ No newline at end of file
