@@ -68,9 +68,8 @@ main = hakyllWith config $ do
 --------------------------------------------------------------------------------
 config :: Configuration
 config = defaultConfiguration
-    { deployCommand = "rsync --checksum -ave 'ssh -p 2222' \
-                      \_site/* \
-                      \jaspervdj@jaspervdj.be:jaspervdj.be/hakyll/"
+    { deployCommand =
+        "rsync --checksum -av _site/* anmitsu:jaspervdj.be/hakyll/"
     }
 
 
